pub type SignatureSize<C> = <FieldBytesSize<C> as Add>::Output;Expand description
Size of a fixed sized signature for the given elliptic curve.
main (development) branch of crypto-glue.pub type SignatureSize<C> = <FieldBytesSize<C> as Add>::Output;Size of a fixed sized signature for the given elliptic curve.